Learn R Programming

bdvis (version 0.1.0)

taxotree: taxotree - Draws a treemap based on Taxonomic hierarchy of records

Description

taxotree - Draws a treemap based on Taxonomic hierarchy of records

Usage

taxotree(indf)

Arguments

indf
input data frame containing biodiversity data set

References

Otegui, J., Arino, A. H., Encinas, M. A., & Pando, F. (2013). Assessing the Primary Data Hosted by the Spanish Node of the Global Biodiversity Information Facility (GBIF). PLoS ONE, 8(1), e55144. doi:10.1371/journal.pone.0055144

Examples

Run this code
taxotree(inat)

Run the code above in your browser using DataLab